@@ -16,6 +16,7 @@ from .SS_MRF_Input import SS_MRF_Input
 from .Reproc_Input import Reproc_Input
 from .SF_Col_Input import SF_Col_Input
 from .TS_Input import TS_Input
+from .HC_Input import HC_Input
 
 __all__ = [
     'MC',
@@ -29,7 +30,8 @@ __all__ = [
     'SS_MRF_Input',
     'Reproc_Input',
     'SF_Col_Input',
-    'TS_Input'
+    'TS_Input',
+    'HC_Input'
 ]
 
-__version__ = '0.1.8'
+__version__ = '0.2.0'
